@@ -11,7 +11,7 @@ Term::Shell::MultiCmd -  Nested Commands Tree in Shell Interface
 
 =cut
 
-our $VERSION = '1.093';
+our $VERSION = '2.01';
 
 =head1 SYNOPSIS
 
@@ -316,6 +316,7 @@ The next example would print any output to a given filehandle:
 
 If it's a function ref, call it with an echo of the user's command
 
+
    my $cli = new Term::Shell::MultiCmd ( -record_cmd => sub {
                                             my $user_cmd = shift;
                                             system "echo '$user_cmd' >> /tmp/history"
@@ -323,6 +324,19 @@ If it's a function ref, call it with an echo of the user's command
                                        ) ;
 
 
+=item * -empty_cmd
+
+Function ref only, call it when user hits 'Return' with no command or args (not even spaces)
+
+   my $cli = new Term::Shell::MultiCmd ( -empty_cmd => sub {
+                                                # Assuming some commands are recorded in $last_repeatable_cmd
+                                                if ( $last_repeatable_cmd ) {
+                                                    # repeat it
+                                                }
+                                          }
+                                       ) ;
+
+
 =back
 
 =cut
@@ -354,7 +368,7 @@ sub new {
     my $class = shift ;
     my %p = _params 'help_cmd=help quit_cmd=quit root_cmd= prompt=shell>
                      history_file= history_size=100 history_more= pager= pager_re=^\|
-                     record_cmd=
+                     record_cmd= empty_cmd=
                      ', @_ ;
 
     # structure rules:
@@ -364,7 +378,7 @@ sub new {
 
     my $o = bless { cmds => { },
                     map {($_, $p{$_})} qw/prompt pager history_file history_size history_more
-                                          help_cmd quit_cmd root_cmd pager pager_re record_cmd
+                                          help_cmd quit_cmd root_cmd pager pager_re record_cmd empty_cmd
                                          /
                   }, ref ( $class ) || $class ;
 
@@ -889,6 +903,7 @@ sub cmd {
 sub _cmd {
     my ($o, $cmd, $path, @args) = @_ ;
     return print $cmd unless ref $cmd ;
+    return $o->{empty_cmd}->() if $o->{empty_cmd} and $cmd eq $o->{cmds} and 0 == length join '', @args;
     return _say "No such command or prefix: " . _join $o, @args if $cmd eq $o->{cmds} ;
     return _help_message($o, -node => $cmd, -path => $path) unless 'ARRAY' eq ref $cmd ; # help message
     my %p = _options $cmd->[3] || '', @args ;
